# Variables d'environnement
NO_DB_DUMP : 
if not already existing, preview will be mounted without dump from prod instance, but with demo datas 

# Dev interaction
### lancement en local pour tester le mode interactif : python -m pynestor preview --interactive --up
